# Long description

- [1. [Optional] Property `Long description > it_s_hard_to_explain`](#it_s_hard_to_explain)

**Title:** Long description

| Type                      | `object`                                                                  |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
|                           |                                                                           |

| Property                                         | Pattern | Type   | Deprecated | Definition | Title/Description                                                                    |
| ------------------------------------------------ | ------- | ------ | ---------- | ---------- | ------------------------------------------------------------------------------------ |
| - [it_s_hard_to_explain](#it_s_hard_to_explain ) | No      | string | No         | -          | This property is really complicated. To explain it we need a whole lot of text,  ... |
|                                                  |         |        |            |            |                                                                                      |

## <a name="it_s_hard_to_explain"></a>1. [Optional] Property `Long description > it_s_hard_to_explain`

| Type                      | `string`                                                                  |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
|                           |                                                                           |

**Description:** This property is really complicated. To explain it we need a whole lot of text, I'm telling you. It all started in 1919 when the children were playing outside and not with computers like kids these days. At the time, I thought to myself "I should create a JSON Schema with a property that is really hard to explain". I did not know what a JSON schema was, in fact I was not alive at the time, but that's what happened, trust me. Anyway this property represents your dreams, but like if your dreams was the reality, but not really. I told you it was hard to explain... In case this is not long enough, here is a Fable of La Fontaine: Rien ne sert de courir ; il faut partir à point. Le Lièvre et la Tortue en sont un témoignage. Gageons, dit celle-ci, que vous n'atteindrez point Sitôt que moi ce but. — Sitôt ? Êtes-vous sage ? Repartit l'animal léger. Ma commère, il vous faut purger Avec quatre grains d'ellébore. — Sage ou non, je parie encore. Ainsi fut fait : et de tous deux On mit près du but les enjeux : Savoir quoi, ce n'est pas l'affaire, Ni de quel juge l'on convint. Notre Lièvre n'avait que quatre pas à faire ; J'entends de ceux qu'il fait lorsque prêt d'être atteint Il s'éloigne des chiens, les renvoie aux Calendes, Et leur fait arpenter les landes. Ayant, dis-je, du temps de reste pour brouter, Pour dormir, et pour écouter D'où vient le vent, il laisse la Tortue Aller son train de Sénateur. Elle part, elle s'évertue ; Elle se hâte avec lenteur. Lui cependant méprise une telle victoire, Tient la gageure à peu de gloire, Croit qu'il y va de son honneur De partir tard. Il broute, il se repose, Il s'amuse à toute autre chose Qu'à la gageure. À la fin quand il vit Que l'autre touchait presque au bout de la carrière, Il partit comme un trait ; mais les élans qu'il fit Furent vains : la Tortue arriva la première. Eh bien ! lui cria-t-elle, avais-je pas raison ? De quoi vous sert votre vitesse ? Moi, l'emporter ! et que serait-ce Si vous portiez une maison ?

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date